var vows = require('vows'),
    assert = require('assert'),
    path = require('path'),
    fs = require('fs'),
    Pack = require('../src/jspkg').Pack;

require('../assets/package');
require('./dependencies');

var tmpPath = path.join(__dirname, 'tmp');
var modulesPath = path.join(__dirname, 'modules');

if (path.existsSync(tmpPath)){
    fs.readdirSync(tmpPath).forEach(function(file){
        fs.unlinkSync(path.join(tmpPath, file));
    });
} else {
    fs.mkdirSync(tmpPath, '777');
}

vows.describe('packager').addBatch({
    'no dependencies': {
        topic: function(){
            return new Pack('a');
        },
        'should have the data attribute': function(topic){
            assert.ok(topic.data);
        },
        'the data attribute should be equal the content of the a.js file': function(topic){
            var a = fs.readFileSync(path.join(modulesPath, 'a.js'));
            assert.equal(''+topic.data, ''+a);
        },
        'creating the file': {
            topic: function(topic){
                topic.write(path.join(tmpPath, 'pkg.js'));
                return 1;
            },
            'should create a file pkb.js file': function(topic){
                assert.ok(path.existsSync(path.join(tmpPath, 'pkg.js')));
            },
            'the pkg.js file should be equal the a.js file': function(topic){
                var pkg = fs.readFileSync(path.join(tmpPath, 'pkg.js'));
                var a = fs.readFileSync(path.join(modulesPath, 'a.js'));
                assert.equal(''+pkg, ''+a);
            }
        }
    },
    'with one depth dependency': {
        topic: function(){
            return new Pack('b');
        },
        'the data attribute should be equal the content of the a.js concatenated with b.js file': function(topic){
            var a = fs.readFileSync(path.join(modulesPath, 'a.js'));
            var b = fs.readFileSync(path.join(modulesPath, 'b.js'));
            assert.equal(''+topic.data, ''+a+b);
        }
    },
    'with two depth dependency': {
        topic: function(){
            return new Pack('c');
        },
        'the data attribute should be equal the content of the a.js concatenated with b.js file': function(topic){
            var a = fs.readFileSync(path.join(modulesPath, 'a.js'));
            var b = fs.readFileSync(path.join(modulesPath, 'b.js'));
            var c = fs.readFileSync(path.join(modulesPath, 'c.js'));
            assert.equal(''+topic.data, ''+a+b+c);
        }
    },
    'module with two requirements': {
        topic: function(){
            return new Pack('x');
        },
        'the data attribute should be equal the content of the a.js concatenated with b.js file': function(topic){
            var a = fs.readFileSync(path.join(modulesPath, 'a.js'));
            var b = fs.readFileSync(path.join(modulesPath, 'b.js'));
            var c = fs.readFileSync(path.join(modulesPath, 'c.js'));
            var z = fs.readFileSync(path.join(modulesPath, 'z.js'));
            var x = fs.readFileSync(path.join(modulesPath, 'x.js'));
            assert.equal(''+topic.data, ''+a+b+c+z+x);
        }
    }
}).export(module);

